Skip to contents

Returns the values of the name column from the survey sheet, excluding any rows where name is NA (such as begin_group / end_group rows that carry no name).

Usage

xlsform_questions(x, ...)

# Default S3 method
xlsform_questions(x, ...)

# S3 method for class 'xlsform'
xlsform_questions(x, ...)

Arguments

x

An xlsform object.

...

Ignored; present for S3 method compatibility.

Value

A character vector of non-NA question names from the survey sheet.

Details

The returned vector is used internally by validate_question_names() to compare question inventories across two forms.

See also

xlsform_referenced_list_names() for list names referenced in the survey; xlsform_defined_list_names() for list names defined in the choices sheet.

Examples

form <- read_xlsform(system.file("extdata/form.xlsx", package = "idem"))

# All question names in the form
xlsform_questions(form)
#>   [1] "audit"                                                     
#>   [2] "start"                                                     
#>   [3] "end"                                                       
#>   [4] "today"                                                     
#>   [5] "deviceid"                                                  
#>   [6] "instance_name"                                             
#>   [7] "introduction"                                              
#>   [8] "survey_modality"                                           
#>   [9] "enum_id"                                                   
#>  [10] "enum_gender"                                               
#>  [11] "enum_age"                                                  
#>  [12] "admin1"                                                    
#>  [13] "admin2"                                                    
#>  [14] "admin3"                                                    
#>  [15] "admin4"                                                    
#>  [16] "cluster_id"                                                
#>  [17] "consent"                                                   
#>  [18] "consent_no_note"                                           
#>  [19] "intro_hh"                                                  
#>  [20] "introduction"                                              
#>  [21] "consented"                                                 
#>  [22] "demographics"                                              
#>  [23] "resp_gender"                                               
#>  [24] "resp_age"                                                  
#>  [25] "resp_hoh_yn"                                               
#>  [26] "hoh_gender"                                                
#>  [27] "hoh_age"                                                   
#>  [28] "hoh_civil_status"                                          
#>  [29] "other_hoh_civil_status"                                    
#>  [30] "setting"                                                   
#>  [31] "hh_size"                                                   
#>  [32] "repeat_intro_hh"                                           
#>  [33] "roster"                                                    
#>  [34] "parent_instance_name"                                      
#>  [35] "person_id"                                                 
#>  [36] "ind_pos"                                                   
#>  [37] "note_resp"                                                 
#>  [38] "ind_name"                                                  
#>  [39] "ind_gender"                                                
#>  [40] "ind_age"                                                   
#>  [41] "check_gender"                                              
#>  [42] "check_age"                                                 
#>  [43] "note_resp_gender_mismatch"                                 
#>  [44] "note_resp_age_mismatch"                                    
#>  [45] "ind_age_under1"                                            
#>  [46] "ind_under5_date_know"                                      
#>  [47] "ind_under5_date"                                           
#>  [48] "ind_under5_event"                                          
#>  [49] "ind_dob_final"                                             
#>  [50] "ind_under5_age_months"                                     
#>  [51] "ind_under5_age_years"                                      
#>  [52] "note_child_age_under5"                                     
#>  [53] "check_age_under5"                                          
#>  [54] "note_child_age_under5_mismatch"                            
#>  [55] "ind_age_2_11"                                              
#>  [56] "ind_f"                                                     
#>  [57] "ind_age_5_17"                                              
#>  [58] "ind_m_age_5_17"                                            
#>  [59] "ind_f_age_5_17"                                            
#>  [60] "ind_age_0_1"                                               
#>  [61] "ind_age_0_4"                                               
#>  [62] "ind_age_0_5"                                               
#>  [63] "ind_f_age_above18"                                         
#>  [64] "ind_m_age_above18"                                         
#>  [65] "ind_woman_repr_age"                                        
#>  [66] "ind_age_schooling"                                         
#>  [67] "ind_potentially_hoh"                                       
#>  [68] "wgss_indiv"                                                
#>  [69] "wgss_ind_pos"                                              
#>  [70] "wgss_person_id"                                            
#>  [71] "wgss_ind_age"                                              
#>  [72] "wgss_ind_gender"                                           
#>  [73] "wgss_ind_name"                                             
#>  [74] "direct_proxy"                                              
#>  [75] "caregiver_available"                                       
#>  [76] "proxy_resp_gender"                                         
#>  [77] "proxy_resp_age"                                            
#>  [78] "wgq_vision"                                                
#>  [79] "wgq_hearing"                                               
#>  [80] "wgq_mobility"                                              
#>  [81] "wgq_cognition"                                             
#>  [82] "wgq_self_care"                                             
#>  [83] "wgq_communication"                                         
#>  [84] "gi_dis_challenges"                                         
#>  [85] "wgss_indiv"                                                
#>  [86] "roster"                                                    
#>  [87] "ind_age_2_11_n"                                            
#>  [88] "ind_f_n"                                                   
#>  [89] "ind_age_5_17_n"                                            
#>  [90] "ind_m_age_5_17_n"                                          
#>  [91] "ind_f_age_5_17_n"                                          
#>  [92] "ind_age_0_1_n"                                             
#>  [93] "ind_age_0_4_n"                                             
#>  [94] "ind_age_0_5_n"                                             
#>  [95] "ind_f_age_above18_n"                                       
#>  [96] "ind_m_age_above18_n"                                       
#>  [97] "ind_age_schooling_n"                                       
#>  [98] "ind_women_repr_age_n"                                      
#>  [99] "ind_hoh_mismatch"                                          
#> [100] "demographics"                                              
#> [101] "displacement"                                              
#> [102] "note_dis_hh"                                               
#> [103] "dis_forced"                                                
#> [104] "dis_area_origin"                                           
#> [105] "dis_reasons"                                               
#> [106] "other_dis_reasons"                                         
#> [107] "dis_main_reasons"                                          
#> [108] "other_dis_main_reasons"                                    
#> [109] "dis_duration"                                              
#> [110] "dis_secondary_n"                                           
#> [111] "displacement"                                              
#> [112] "aap"                                                       
#> [113] "cpa_priority_challenge_note"                               
#> [114] "cpa_preferred_modality_1"                                  
#> [115] "other_cpa_preferred_modality_1"                            
#> [116] "cpa_priority_support_ngo_1"                                
#> [117] "other_cpa_priority_support_ngo_1"                          
#> [118] "cpa_preferred_modality_2"                                  
#> [119] "other_cpa_preferred_modality_2"                            
#> [120] "cpa_priority_support_ngo_2"                                
#> [121] "other_cpa_priority_support_ngo_2"                          
#> [122] "cpa_priority_support_cash"                                 
#> [123] "aap_received_assistance_12m"                               
#> [124] "aap_received_assistance_date"                              
#> [125] "aap_received_assistance_type"                              
#> [126] "other_aap_received_assistance_type"                        
#> [127] "aap_relevance_assistance"                                  
#> [128] "aap_relevance_assistance_reason"                           
#> [129] "other_aap_relevance_assistance_reason"                     
#> [130] "aap_satisfaction_assistance"                               
#> [131] "aap_satisfaction_challenges"                               
#> [132] "other_aap_satisfaction_challenges"                         
#> [133] "aap_assistance_improves_living_conditions"                 
#> [134] "other_aap_assistance_improves_living_conditions"           
#> [135] "aap_assistance_improves_living_conditions_challenges"      
#> [136] "other_aap_assistance_improves_living_conditions_challenges"
#> [137] "aap_assistance_coverage"                                   
#> [138] "aap_satisfaction_workers_behaviour"                        
#> [139] "aap_satisfaction_workers_behaviour_reason"                 
#> [140] "other_aap_satisfaction_workers_behaviour_reason"           
#> [141] "aap_consultation_assistance_yn"                            
#> [142] "aap_consultation_assistance_opinions"                      
#> [143] "aap_preferred_means_feedback"                              
#> [144] "other_aap_preferred_means_feedback"                        
#> [145] "aap_cfm_channels_awareness"                                
#> [146] "other_aap_cfm_channels_awareness"                          
#> [147] "aap_cfm_use"                                               
#> [148] "aap_information_needs"                                     
#> [149] "other_aap_information_needs"                               
#> [150] "aap_preferred_source_info"                                 
#> [151] "other_aap_preferred_source_info"                           
#> [152] "aap_received_type_info_aid"                                
#> [153] "aap_received_source_info_aid"                              
#> [154] "other_aap_received_source_info_aid"                        
#> [155] "aap_received_channel_info_aid"                             
#> [156] "other_aap_received_channel_info_aid"                       
#> [157] "aap_trusted_channel_info"                                  
#> [158] "other_aap_trusted_channel_info"                            
#> [159] "hesper"                                                    
#> [160] "hesper_drinking_water"                                     
#> [161] "hesper_food"                                               
#> [162] "hesper_shelter"                                            
#> [163] "hesper_toilet"                                             
#> [164] "hesper_clean"                                              
#> [165] "hesper_clean_women"                                        
#> [166] "hesper_clothes_etc"                                        
#> [167] "hesper_income_livelihood"                                  
#> [168] "hesper_health"                                             
#> [169] "hesper_health_care_men"                                    
#> [170] "hesper_health_care_women"                                  
#> [171] "hesper_distress"                                           
#> [172] "hesper_safety"                                             
#> [173] "hesper_education"                                          
#> [174] "hesper_care"                                               
#> [175] "hesper_support"                                            
#> [176] "hesper_separation"                                         
#> [177] "hesper_displaced"                                          
#> [178] "hesper_information"                                        
#> [179] "hesper_aid"                                                
#> [180] "hesper_respect"                                            
#> [181] "hesper_movement"                                           
#> [182] "hesper_time"                                               
#> [183] "hesper_community_intro"                                    
#> [184] "hesper_law"                                                
#> [185] "hesper_gbv"                                                
#> [186] "hesper_drug"                                               
#> [187] "hesper_mental_health"                                      
#> [188] "hesper_care_community"                                     
#> [189] "hesper_priority_intro"                                     
#> [190] "hesper_priority_first"                                     
#> [191] "hesper_priority_second"                                    
#> [192] "hesper_priority_third"                                     
#> [193] "hesper"                                                    
#> [194] "aap"                                                       
#> [195] "edu"                                                       
#> [196] "edu_ind_note"                                              
#> [197] "edu_ind"                                                   
#> [198] "edu_ind_pos"                                               
#> [199] "edu_person_id"                                             
#> [200] "edu_ind_age"                                               
#> [201] "edu_ind_gender"                                            
#> [202] "edu_ind_age_schooling"                                     
#> [203] "edu_ind_name"                                              
#> [204] "edu_ind_gender_en"                                         
#> [205] "edu_ind_gender_fr"                                         
#> [206] "edu_access"                                                
#> [207] "edu_level_grade"                                           
#> [208] "edu_disrupted_hazards"                                     
#> [209] "edu_disrupted_teacher"                                     
#> [210] "edu_disrupted_displaced"                                   
#> [211] "edu_disrupted_attack"                                      
#> [212] "edu_barrier"                                               
#> [213] "other_edu_barrier"                                         
#> [214] "edu_financial_barrier"                                     
#> [215] "other_edu_financial_barrier"                               
#> [216] "edu_other_yn"                                              
#> [217] "edu_other_type"                                            
#> [218] "edu_ind"                                                   
#> [219] "edu_community_modality"                                    
#> [220] "edu"                                                       
#> [221] "shelter"                                                   
#> [222] "snfi_note"                                                 
#> [223] "snfi_shelter_type"                                         
#> [224] "snfi_shelter_type_collective"                              
#> [225] "other_snfi_shelter_type_collective"                        
#> [226] "snfi_shelter_type_individual"                              
#> [227] "other_snfi_shelter_type_individual"                        
#> [228] "snfi_shelter_damage"                                       
#> [229] "snfi_shelter_damage_when"                                  
#> [230] "snfi_shelter_damage_cause"                                 
#> [231] "other_snfi_shelter_damage_cause"                           
#> [232] "snfi_shelter_damage_barriers_repairs"                      
#> [233] "snfi_shelter_issue"                                        
#> [234] "other_snfi_shelter_issue"                                  
#> [235] "snfi_fds_cooking"                                          
#> [236] "snfi_fds_cooking_issue"                                    
#> [237] "other_snfi_fds_cooking_issue"                              
#> [238] "snfi_fds_sleeping"                                         
#> [239] "snfi_fds_sleeping_issue"                                   
#> [240] "other_snfi_fds_sleeping_issue"                             
#> [241] "snfi_fds_storing"                                          
#> [242] "snfi_fds_storing_issue"                                    
#> [243] "other_snfi_fds_storing_issue"                              
#> [244] "snfi_sufficient_clothes"                                   
#> [245] "snfi_essential_items_missing"                              
#> [246] "other_snfi_essential_items_missing"                        
#> [247] "shelter"                                                   
#> [248] "energy"                                                    
#> [249] "energy_lighting_source"                                    
#> [250] "other_energy_lighting_source"                              
#> [251] "energy"                                                    
#> [252] "hlp"                                                       
#> [253] "hlp_occupancy"                                             
#> [254] "other_hlp_occupancy"                                       
#> [255] "hlp_risk_eviction"                                         
#> [256] "hlp_threat_eviction"                                       
#> [257] "hlp"                                                       
#> [258] "wash"                                                      
#> [259] "wash_note"                                                 
#> [260] "wash_drinking_water_source"                                
#> [261] "other_wash_drinking_water_source"                          
#> [262] "wash_drinking_water_time_yn"                               
#> [263] "wash_drinking_water_time_int"                              
#> [264] "wash_drinking_water_time_sl"                               
#> [265] "wash_hwise_drink"                                          
#> [266] "wash_hwise_hands"                                          
#> [267] "wash_hwise_worry"                                          
#> [268] "wash_hwise_plans"                                          
#> [269] "wash_hwise_12_none"                                        
#> [270] "wash_hwise_12_sleep"                                       
#> [271] "wash_hwise_12_food"                                        
#> [272] "wash_hwise_12_clothes"                                     
#> [273] "wash_hwise_12_angry"                                       
#> [274] "wash_hwise_12_body"                                        
#> [275] "wash_hwise_12_shame"                                       
#> [276] "wash_hwise_12_interrupt"                                   
#> [277] "wash_drinking_water_quantity"                              
#> [278] "wash_drinking_water_acceptable"                            
#> [279] "wash_water_access_issue"                                   
#> [280] "other_wash_water_access_issue"                             
#> [281] "wash_drinking_water_other_sources"                         
#> [282] "other_wash_drinking_water_other_sources"                   
#> [283] "wash_drinking_water_person_fetch"                          
#> [284] "wash_drinking_water_person_trips"                          
#> [285] "wash_drinking_water_piped_supply"                          
#> [286] "wash_water_availability_yn"                                
#> [287] "wash_water_availability_issue"                             
#> [288] "other_wash_water_availability_issue"                       
#> [289] "wash_drinking_water_supplied_hours"                        
#> [290] "wash_drinking_water_days_unavailable"                      
#> [291] "wash_drinking_water_store_insufficient_yn"                 
#> [292] "wash_drinking_water_tank_yn"                               
#> [293] "wash_drinking_water_tank_litres"                           
#> [294] "wash_drinking_water_tank_times_filled"                     
#> [295] "wash_drinking_water_store_small_containers"                
#> [296] "wash_drinking_water_safer_yn"                              
#> [297] "wash_drinking_water_safer_details"                         
#> [298] "other_wash_drinking_water_safer_details"                   
#> [299] "wash_sanitation_facility"                                  
#> [300] "other_wash_sanitation_facility"                            
#> [301] "wash_sanitation_facility_sharing_yn"                       
#> [302] "wash_sanitation_facility_sharing_n"                        
#> [303] "wash_sanitation_sharing_public"                            
#> [304] "wash_sanitation_toilet_design"                             
#> [305] "wash_sanitation_access_features"                           
#> [306] "wash_sanitation_facility_location"                         
#> [307] "wash_sanitation_use_of_facility"                           
#> [308] "wash_sanitation_use_toilet"                                
#> [309] "wash_sanitation_use_toilet_reason"                         
#> [310] "other_wash_sanitation_use_toilet_reason"                   
#> [311] "wash_sanitation_toilet_risks"                              
#> [312] "other_wash_sanitation_toilet_risks"                        
#> [313] "wash_sanitation_access_issue"                              
#> [314] "other_wash_sanitation_access_issue"                        
#> [315] "wash_sanitation_emptied_yn"                                
#> [316] "wash_sanitation_emptied_where"                             
#> [317] "other_wash_sanitation_emptied_where"                       
#> [318] "wash_sanitation_outlet_pipe"                               
#> [319] "wash_sanitation_outlet_pipe_where"                         
#> [320] "other_wash_sanitation_outlet_pipe_where"                   
#> [321] "wash_sanitation_facility_leak"                             
#> [322] "wash_sanitation_septic_discharge"                          
#> [323] "other_wash_sanitation_septic_discharge"                    
#> [324] "wash_sanitation_septic_age"                                
#> [325] "wash_sanitation_latrine_emptied"                           
#> [326] "wash_sanitation_emptied_who"                               
#> [327] "other_wash_sanitation_emptied_who"                         
#> [328] "wash_sanitation_excreta_released"                          
#> [329] "other_wash_sanitation_excreta_released"                    
#> [330] "wash_sanitation_adaptation"                                
#> [331] "other_wash_sanitation_adaptation"                          
#> [332] "wash_sanitation_environment"                               
#> [333] "wash_sanitation_dispose_garbage"                           
#> [334] "wash_sanitation_dispose_water"                             
#> [335] "wash_handwashing_facility"                                 
#> [336] "other_wash_handwashing_facility"                           
#> [337] "wash_handwashing_facility_observed_water_yn"               
#> [338] "wash_handwashing_facility_reported"                        
#> [339] "other_wash_handwashing_facility_reported"                  
#> [340] "wash_handwashing_facility_water_reported_yn"               
#> [341] "wash_soap_observed_yn"                                     
#> [342] "wash_soap_observed_type"                                   
#> [343] "other_wash_soap_observed_type"                             
#> [344] "wash_soap_reported_yn"                                     
#> [345] "wash_soap_reported_type"                                   
#> [346] "other_wash_soap_reported_type"                             
#> [347] "wash_hygiene_menstrual_privacy_yn"                         
#> [348] "wash_hygiene_menstrual_materials"                          
#> [349] "other_wash_hygiene_menstrual_materials"                    
#> [350] "wash_hygiene_menstrual_materials_reusable_yn"              
#> [351] "wash_hygiene_menstrual_missed_activities"                  
#> [352] "wash_hygiene_menstrual_missed_social_yn"                   
#> [353] "wash_hygiene_menstrual"                                    
#> [354] "other_wash_hygiene_menstrual"                              
#> [355] "wash_hygiene_menstrual_enough_materials_yn"                
#> [356] "wash_hygiene_menstrual_issue"                              
#> [357] "other_wash_hygiene_menstrual_issue"                        
#> [358] "wash_hygiene_menstrual_preferred"                          
#> [359] "other_wash_hygiene_menstrual_preferred"                    
#> [360] "wash_hygiene_menstrual_place"                              
#> [361] "wash_hygiene_adaptation"                                   
#> [362] "other_wash_hygiene_adaptation"                             
#> [363] "wash_bathing_facility_yn"                                  
#> [364] "wash_hygiene_nfi"                                          
#> [365] "other_wash_hygiene_nfi"                                    
#> [366] "wash_bathing_facility_issue"                               
#> [367] "other_wash_bathing_facility_issue"                         
#> [368] "wash_sanqol5_disease"                                      
#> [369] "wash_sanqol5_disg"                                         
#> [370] "wash_sanqol5_seen"                                         
#> [371] "wash_sanqol5_shame"                                        
#> [372] "wash_sanqol5_unsafe"                                       
#> [373] "wash_sanqol5_od_disease"                                   
#> [374] "wash_sanqol5_od_disg"                                      
#> [375] "wash_sanqol5_od_seen"                                      
#> [376] "wash_sanqol5_od_shame"                                     
#> [377] "wash_sanqol5_od_unsafe"                                    
#> [378] "wash_water_adaptation"                                     
#> [379] "other_wash_water_adaptation"                               
#> [380] "wash_productive_water_quantity"                            
#> [381] "wash_chl_info"                                             
#> [382] "wash_chl_info_src"                                         
#> [383] "other_wash_chl_info_src"                                   
#> [384] "wash_chl_actions_sick"                                     
#> [385] "other_wash_chl_actions_sick"                               
#> [386] "wash_chl_origin"                                           
#> [387] "other_wash_chl_origin"                                     
#> [388] "wash_chl_transmission"                                     
#> [389] "other_wash_chl_transmission"                               
#> [390] "wash_chl_health_actions"                                   
#> [391] "other_wash_chl_health_actions"                             
#> [392] "wash_chl_health_practices"                                 
#> [393] "wash_chl_ors"                                              
#> [394] "wash_chl_ors_preparation"                                  
#> [395] "other_wash_chl_ors_preparation"                            
#> [396] "wash"                                                      
#> [397] "fsl"                                                       
#> [398] "fsl_note"                                                  
#> [399] "fsl_respondent"                                            
#> [400] "fsl_fcs_cereal"                                            
#> [401] "fsl_fcs_legumes"                                           
#> [402] "fsl_fcs_dairy"                                             
#> [403] "fsl_fcs_meat"                                              
#> [404] "fsl_fcs_veg"                                               
#> [405] "fsl_fcs_fruit"                                             
#> [406] "fsl_fcs_oil"                                               
#> [407] "fsl_fcs_sugar"                                             
#> [408] "fsl_fcs_condiments"                                        
#> [409] "fsl_rcsi_note"                                             
#> [410] "fsl_rcsi_lessquality"                                      
#> [411] "fsl_rcsi_borrow"                                           
#> [412] "fsl_rcsi_mealsize"                                         
#> [413] "fsl_rcsi_mealadult"                                        
#> [414] "fsl_rcsi_mealnb"                                           
#> [415] "fsl_hhs_nofoodhh"                                          
#> [416] "fsl_hhs_nofoodhh_freq"                                     
#> [417] "fsl_hhs_sleephungry"                                       
#> [418] "fsl_hhs_sleephungry_freq"                                  
#> [419] "fsl_hhs_alldaynight"                                       
#> [420] "fsl_hhs_alldaynight_freq"                                  
#> [421] "fsl_source_food"                                           
#> [422] "other_fsl_source_food"                                     
#> [423] "fsl_source_food_ranked"                                    
#> [424] "fsl_lcsi_note"                                             
#> [425] "fsl_lcsi_stress1"                                          
#> [426] "fsl_lcsi_stress2"                                          
#> [427] "fsl_lcsi_stress3"                                          
#> [428] "fsl_lcsi_stress4"                                          
#> [429] "fsl_lcsi_crisis1"                                          
#> [430] "fsl_lcsi_crisis2"                                          
#> [431] "fsl_lcsi_crisis3"                                          
#> [432] "fsl_lcsi_emergency1"                                       
#> [433] "fsl_lcsi_emergency2"                                       
#> [434] "fsl_lcsi_emergency3"                                       
#> [435] "fsl_lcsi_other_reason"                                     
#> [436] "other_fsl_lcsi_other_reason"                               
#> [437] "fsl_lcsi_en_stress1"                                       
#> [438] "fsl_lcsi_en_stress2"                                       
#> [439] "fsl_lcsi_en_stress3"                                       
#> [440] "fsl_lcsi_en_stress4"                                       
#> [441] "fsl_lcsi_en_crisis1"                                       
#> [442] "fsl_lcsi_en_crisis2"                                       
#> [443] "fsl_lcsi_en_crisis3"                                       
#> [444] "fsl_lcsi_en_emergency1"                                    
#> [445] "fsl_lcsi_en_emergency2"                                    
#> [446] "fsl_lcsi_en_emergency3"                                    
#> [447] "fsl_lcsi_en_other_reason"                                  
#> [448] "other_fsl_lcsi_en_other_reason"                            
#> [449] "fsl_liv_act"                                               
#> [450] "fsl_crop_type"                                             
#> [451] "other_fsl_crop_type"                                       
#> [452] "fsl_crop_area_change"                                      
#> [453] "fsl_crop_diff"                                             
#> [454] "other_fsl_crop_diff"                                       
#> [455] "fsl_crop_harv_change"                                      
#> [456] "note_crop_harv_change"                                     
#> [457] "fsl_livestock_type"                                        
#> [458] "other_fsl_livestock_type"                                  
#> [459] "grp_sub_livestock"                                         
#> [460] "grp_oxen"                                                  
#> [461] "fsl_oxen_n_now"                                            
#> [462] "fsl_oxen_n_ly"                                             
#> [463] "grp_oxen"                                                  
#> [464] "fsl_oxen_n_change"                                         
#> [465] "other_fsl_oxen_n_change"                                   
#> [466] "fsl_oxen_diff"                                             
#> [467] "other_fsl_oxen_diff"                                       
#> [468] "grp_camel"                                                 
#> [469] "fsl_camel_n_now"                                           
#> [470] "fsl_camel_n_ly"                                            
#> [471] "grp_camel"                                                 
#> [472] "fsl_camel_n_change"                                        
#> [473] "other_fsl_camel_n_change"                                  
#> [474] "fsl_camel_diff"                                            
#> [475] "other_fsl_camel_diff"                                      
#> [476] "grp_cattle"                                                
#> [477] "fsl_cattle_n_now"                                          
#> [478] "fsl_cattle_n_ly"                                           
#> [479] "grp_cattle"                                                
#> [480] "fsl_cattle_n_change"                                       
#> [481] "other_fsl_cattle_n_change"                                 
#> [482] "fsl_cattle_diff"                                           
#> [483] "other_fsl_cattle_diff"                                     
#> [484] "grp_horse"                                                 
#> [485] "fsl_horse_n_now"                                           
#> [486] "fsl_horse_n_ly"                                            
#> [487] "grp_horse"                                                 
#> [488] "fsl_horse_n_change"                                        
#> [489] "other_fsl_horse_n_change"                                  
#> [490] "fsl_horse_diff"                                            
#> [491] "other_fsl_horse_diff"                                      
#> [492] "grp_mule"                                                  
#> [493] "fsl_mule_n_now"                                            
#> [494] "fsl_mule_n_ly"                                             
#> [495] "grp_mule"                                                  
#> [496] "fsl_mule_n_change"                                         
#> [497] "other_fsl_mule_n_change"                                   
#> [498] "fsl_mule_diff"                                             
#> [499] "other_fsl_mule_diff"                                       
#> [500] "grp_donkey"                                                
#> [501] "fsl_donkey_n_now"                                          
#> [502] "fsl_donkey_n_ly"                                           
#> [503] "grp_donkey"                                                
#> [504] "fsl_donkey_n_change"                                       
#> [505] "other_fsl_donkey_n_change"                                 
#> [506] "fsl_donkey_diff"                                           
#> [507] "other_fsl_donkey_diff"                                     
#> [508] "grp_sheep"                                                 
#> [509] "fsl_sheep_n_now"                                           
#> [510] "fsl_sheep_n_ly"                                            
#> [511] "grp_sheep"                                                 
#> [512] "fsl_sheep_n_change"                                        
#> [513] "other_fsl_sheep_n_change"                                  
#> [514] "fsl_sheep_diff"                                            
#> [515] "other_fsl_sheep_diff"                                      
#> [516] "grp_goat"                                                  
#> [517] "fsl_goat_n_now"                                            
#> [518] "fsl_goat_n_ly"                                             
#> [519] "grp_goat"                                                  
#> [520] "fsl_goat_n_change"                                         
#> [521] "other_fsl_goat_n_change"                                   
#> [522] "fsl_goat_diff"                                             
#> [523] "other_fsl_goat_diff"                                       
#> [524] "grp_poultry"                                               
#> [525] "fsl_poultry_n_now"                                         
#> [526] "fsl_poultry_n_ly"                                          
#> [527] "grp_poultry"                                               
#> [528] "fsl_poultry_n_change"                                      
#> [529] "other_fsl_poultry_n_change"                                
#> [530] "fsl_poultry_diff"                                          
#> [531] "other_fsl_poultry_diff"                                    
#> [532] "grp_sub_livestock"                                         
#> [533] "grp_food_storing"                                          
#> [534] "fsl_food_storing"                                          
#> [535] "other_fsl_food_storing"                                    
#> [536] "grp_food_storing"                                          
#> [537] "fsl"                                                       
#> [538] "cm"                                                        
#> [539] "cm_note"                                                   
#> [540] "cm_income_total"                                           
#> [541] "cm_income_sources_reduced_1"                               
#> [542] "other_cm_income_sources_reduced_1"                         
#> [543] "cm_income_sources_reduced_2"                               
#> [544] "other_cm_income_sources_reduced_2"                         
#> [545] "cm_expenditure_frequent"                                   
#> [546] "other_cm_expenditure_frequent"                             
#> [547] "cm_expenditure_frequent_note"                              
#> [548] "cm_expenditure_frequent_food"                              
#> [549] "cm_expenditure_frequent_rent"                              
#> [550] "cm_expenditure_frequent_water"                             
#> [551] "cm_expenditure_frequent_nfi"                               
#> [552] "cm_expenditure_frequent_utilities"                         
#> [553] "cm_expenditure_frequent_fuel"                              
#> [554] "cm_expenditure_frequent_transportation"                    
#> [555] "cm_expenditure_frequent_communication"                     
#> [556] "cm_expenditure_frequent_other"                             
#> [557] "cm_expenditure_infrequent"                                 
#> [558] "other_cm_expenditure_infrequent"                           
#> [559] "cm_expenditure_infrequent_note"                            
#> [560] "cm_expenditure_infrequent_shelter"                         
#> [561] "cm_expenditure_infrequent_clothing"                        
#> [562] "cm_expenditure_infrequent_nfi"                             
#> [563] "cm_expenditure_infrequent_health"                          
#> [564] "cm_expenditure_infrequent_education"                       
#> [565] "cm_expenditure_infrequent_debt"                            
#> [566] "cm_expenditure_infrequent_other"                           
#> [567] "cm_market_time"                                            
#> [568] "cm_market_barriers_access"                                 
#> [569] "other_cm_market_barriers_access"                           
#> [570] "cm_market_barriers_purchase"                               
#> [571] "other_cm_market_barriers_purchase"                         
#> [572] "cm"                                                        
#> [573] "health"                                                    
#> [574] "health_note"                                               
#> [575] "health_ind"                                                
#> [576] "health_ind_pos"                                            
#> [577] "health_person_id"                                          
#> [578] "health_ind_age"                                            
#> [579] "health_ind_gender"                                         
#> [580] "health_ind_name"                                           
#> [581] "health_ind_gender_fr"                                      
#> [582] "health_ind_healthcare_needed"                              
#> [583] "health_ind_healthcare_needed_y"                            
#> [584] "health_ind_healthcare_received"                            
#> [585] "health_ind_healthcare_needed_type"                         
#> [586] "other_health_ind_healthcare_needed_type"                   
#> [587] "health_ind_healthcare_received_location"                   
#> [588] "other_health_ind_healthcare_received_location"             
#> [589] "health_ind"                                                
#> [590] "health_ind_healthcare_needed_n"                            
#> [591] "health_facility_time"                                      
#> [592] "health_barriers"                                           
#> [593] "other_health_barriers"                                     
#> [594] "health_barriers_main"                                      
#> [595] "other_health_barriers_main"                                
#> [596] "health"                                                    
#> [597] "nutrition"                                                 
#> [598] "nut_ind_note"                                              
#> [599] "nut_ind"                                                   
#> [600] "nut_ind_pos"                                               
#> [601] "nut_person_id"                                             
#> [602] "nut_ind_age"                                               
#> [603] "nut_ind_gender"                                            
#> [604] "nut_ind_name"                                              
#> [605] "nut_ind_age_0_4"                                           
#> [606] "nut_ind_under5_age_months"                                 
#> [607] "nut_ind_age_vitamina"                                      
#> [608] "nut_ind_age_deworming"                                     
#> [609] "nut_ind_under5_sick_yn"                                    
#> [610] "nut_ind_under5_sick_symptoms"                              
#> [611] "other_nut_ind_under5_sick_symptoms"                        
#> [612] "nut_ind_under5_sick_location"                              
#> [613] "other_nut_ind_under5_sick_location"                        
#> [614] "nut_ind_under5_vitamina"                                   
#> [615] "nut_ind_under5_deworming"                                  
#> [616] "nut_ind"                                                   
#> [617] "nut_treat_acute_malnutrition"                              
#> [618] "nutrition"                                                 
#> [619] "protection"                                                
#> [620] "prot_needs_intro"                                          
#> [621] "prot_needs_1_services"                                     
#> [622] "prot_needs_1_services_threats"                             
#> [623] "prot_needs_1_services_population"                          
#> [624] "prot_needs_1_justice"                                      
#> [625] "prot_needs_1_justice_threats"                              
#> [626] "prot_needs_1_justice_population"                           
#> [627] "prot_needs_2_activities"                                   
#> [628] "prot_needs_2_activities_threats"                           
#> [629] "prot_needs_2_activities_population"                        
#> [630] "prot_needs_2_social"                                       
#> [631] "prot_needs_2_social_threats"                               
#> [632] "prot_needs_2_social_population"                            
#> [633] "prot_needs_3_movement"                                     
#> [634] "other_prot_needs_3_movement"                               
#> [635] "prot_needs_3_movement_threats"                             
#> [636] "prot_needs_3_movement_population"                          
#> [637] "prot_concern_introduction"                                 
#> [638] "prot_concern_hh_note"                                      
#> [639] "prot_concern_freq_cope"                                    
#> [640] "prot_concern_freq_hlp"                                     
#> [641] "prot_concern_freq_displaced"                               
#> [642] "prot_concern_freq_home_crime"                              
#> [643] "prot_concern_hh_freq_violence"                             
#> [644] "prot_concern_hh_freq_explosive"                            
#> [645] "prot_concern_hh_freq_kidnapping"                           
#> [646] "prot_concern_hh_freq_forcedrecruitment"                    
#> [647] "prot_concern_hh_freq_discrimination"                       
#> [648] "prot_concern_freq_gbv_walking"                             
#> [649] "prot_concern_freq_gbv_areas"                               
#> [650] "prot_concern_freq_gbv_areas_type"                          
#> [651] "prot_concern_impact"                                       
#> [652] "prot_child_sep"                                            
#> [653] "prot_child_sep_girls_n"                                    
#> [654] "prot_child_sep_boys_n"                                     
#> [655] "prot_child_sep_reason"                                     
#> [656] "prot_child_sep_reason_other"                               
#> [657] "prot_ind"                                                  
#> [658] "prot_ind_pos"                                              
#> [659] "prot_person_id"                                            
#> [660] "prot_ind_age"                                              
#> [661] "prot_ind_gender"                                           
#> [662] "prot_ind_name"                                             
#> [663] "prot_child_work"                                           
#> [664] "prot_child_labour"                                         
#> [665] "prot_ind"                                                  
#> [666] "ch_pr_behaviour_change"                                    
#> [667] "prot_id_yn"                                                
#> [668] "prot_id_who"                                               
#> [669] "prot_id_missing_reason"                                    
#> [670] "prot_id_missing_reason_other"                              
#> [671] "prot_legal_yn"                                             
#> [672] "prot_legal_yn_other"                                       
#> [673] "prot_legal_barriers"                                       
#> [674] "prot_legal_barriers_other"                                 
#> [675] "prot_legal_barriers_who"                                   
#> [676] "prot_adult_sep"                                            
#> [677] "prot_adult_sep_reason"                                     
#> [678] "prot_adult_sep_reason_other"                               
#> [679] "prot_adult_sep_mechanism"                                  
#> [680] "prot_mines"                                                
#> [681] "prot_mines_other"                                          
#> [682] "prot_services_availability"                                
#> [683] "durable_solutions"                                         
#> [684] "ds_plans"                                                  
#> [685] "ds_plans_timeline"                                         
#> [686] "durable_solutions"                                         
#> [687] "shocks_risks"                                              
#> [688] "hazard_env_type"                                           
#> [689] "hazard_sp_type"                                            
#> [690] "shocks_risks"                                              
#> [691] "gender_inclusion"                                          
#> [692] "gi_responsible_note2"                                      
#> [693] "gi_responsible_farming"                                    
#> [694] "gi_responsible_caring"                                     
#> [695] "gi_responsible_water"                                      
#> [696] "gi_responsible_firewood"                                   
#> [697] "gi_responsible_chores"                                     
#> [698] "gi_responsible_assistance"                                 
#> [699] "gi_responsible_food"                                       
#> [700] "gi_responsible_nonfood"                                    
#> [701] "gi_responsible_clothes"                                    
#> [702] "gender_inclusion"                                          
#> [703] "consented"                                                 
#> [704] "location"                                                  
#> [705] "household_geopoint"                                        
#> [706] "location"                                                  
#> [707] "final_note"                                                
#> [708] "final_text"                                                

# Count questions
length(xlsform_questions(form))
#> [1] 708